# aws-policy-generator

aws-policy-generator is a utility that allows for simple generation of IAM policies.

## Features

aws-policy-generator allows you to generate list-only, read-only, read-write or full-access policies for any AWS service via the command-line or a YAML config file.

## Installation

As easy as:

```
pip install aws-policy-generator
```

## Example

Here are simple examples for all the use cases above. More example code can be found in the `tests` directory.

# Documentation

Coming soon. In the meantime each function already has documentation - check the sources. For example usage, see the tests.

# Licence

MIT
